@@ -72,8 +72,6 @@ OC.L10N.register(
     "Description: %s" : "Leírás: %s",
     "Where: %s" : "Hely: %s",
     "%1$s via %2$s" : "%1$s – %2$s",
-    "In %1$s %2$s on %3$s for the entire day" : "%1$s-en %2$s %3$s-kor az teljes napra",
-    "In %1$s %2$s on %3$s between %4$s - %5$s" : "%1$s-en %2$s %3$s-kor %4$s - %5$sközött",
     "Could not generate when statement" : "Nem sikerlt létrehozni a mikor állítást",
     "Every Day for the entire day" : "Minden Nap a teljes napra",
     "Every Day for the entire day until %1$s" : "Minden Nap a teljes napon eddig %1$s",
@@ -153,12 +151,10 @@ OC.L10N.register(
     "Second" : "Másodperc",
     "Third" : "Harmadik",
     "Fourth" : "Negyedik",
-    "Fifty" : "Ötödik",
     "Last" : "Utolsó",
     "Second Last" : "Második Utolsó",
     "Third Last" : "Harmadik Utolsó",
     "Fourth Last" : "Negyedik Utolsó",
-    "Fifty Last" : "Ötödik Utolsó",
     "Contacts" : "Névjegyek",
     "{actor} created address book {addressbook}" : "{actor} létrehozta a következő címjegyzéket: {addressbook}",
     "You created address book {addressbook}" : "Létrehozta a következő címjegyzéket: {addressbook}",
@@ -196,7 +192,6 @@ OC.L10N.register(
     "Could not rename part file to final file, canceled by hook" : "A részleges fájl nem nevezhető át a végleges fájllá, a hurok megszakította",
     "Could not rename part file to final file" : "A részleges fájl nem nevezhető át a végleges fájllá",
     "Failed to check file size: %1$s" : "A fájlméret nem ellenőrizhető: %1$s",
-    "Could not open file" : "A fájl nem nyitható meg",
     "Encryption not ready: %1$s" : "A titkosítás nincs kész: %1$s",
     "Failed to open file: %1$s" : "A fájl megnyitása sikertelen: %1$s",
     "Failed to unlink: %1$s" : "A hivatkozás eltávolítása sikertelen: %1$s",
@@ -270,10 +265,9 @@ OC.L10N.register(
     "Are you accepting the invitation?" : "Elfogadja az meghívást?",
     "Tentative" : "Feltételes",
     "Your attendance was updated successfully." : "A részvétele frissítése sikeres.",
-    "To-dos" : "Teendők",
     "Time:" : "Idő:",
+    "Could not open file" : "A fájl nem nyitható meg",
     "Invalid chunk name" : "Érvénytelen darabnév",
-    "Could not rename part file assembled from chunks" : "Nem lehet átnevezni a darabokból összeállított részleges fájlt",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Ha beállítja a munkaidejét, akkor más felhasználók a megbeszélések létrehozásakor látni fogják, hogy Ön mikor nem érhető el."
+    "Could not rename part file assembled from chunks" : "Nem lehet átnevezni a darabokból összeállított részleges fájlt"
 },
 "nplurals=2; plural=(n != 1);");
