@@ -46,6 +46,7 @@ OC.L10N.register(
     "Failed to authorize" : "Ezin izan da baimendu",
     "Invalid folder path" : "Karpeta bide baliogabea",
     "Folder not found" : "Ez da karpeta aurkitu",
+    "No favorites" : "Gogokorik ez",
     "Upload (max. %s)" : "Igo (%s gehienez)",
     "Accept" : "Onartu",
     "Reject" : "Ukatu",
@@ -75,8 +76,7 @@ OC.L10N.register(
     "Your have used your space quota and cannot upload files anymore" : "Zure espazio-kuota erabili duzu eta ezin duzu fitxategi gehiago kargatu",
     "You don’t have permission to upload or create files here" : "Ez duzu baimenik fitxategiak hona kargatu edo hemen sortzeko",
     "Favorite" : "Gogokoa",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\" ekintza behar bezala exekutatu da",
-    "\"{displayName}\" action failed" : "\"{displayName}\" ekintzak huts egin du",
+    "Back" : "Itzuli",
     "Toggle selection for file \"{displayName}\"" : "Ordeztu hautatutakoa  \"{displayName}\" fitxategiarekin",
     "Toggle selection for folder \"{displayName}\"" : "Ordeztu hautatutakoa  \"{displayName}\" karpetarekin",
     "File is loading" : "Fitxategia kargatzen ari da",
@@ -103,8 +103,11 @@ OC.L10N.register(
     "(selected)" : "(hautatuta)",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\"-k huts egin du elementu batzuetan",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" multzoko ekintza behar bezala exekutatu da",
+    "\"{displayName}\" action failed" : "\"{displayName}\" ekintzak huts egin du",
     "{count} selected" : "{count} hautatuta",
     "List of files and folders." : "Fitxategi eta karpeten zerrenda.",
+    "You don’t have permission to upload or create files here." : "Ez duzu baimenik fitxategiak hona kargatu edo hemen sortzeko.",
+    "You have used your space quota and cannot upload files anymore." : "Zure espazio-kuota erabili duzu eta ezin duzu fitxategi gehiago kargatu.",
     "Column headers with buttons are sortable." : "Botoiak dituzten zutabeen goiburuak ordena daitezke.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Zerrenda hau ez da guztiz ikusten errendimendu arrazoiengatik. Fitxategiak zerrendan zehar nabigatzen duten heinean bistaratuko dira.",
     "File not found" : "Ez da fitxategia aurkitu",
@@ -151,7 +154,7 @@ OC.L10N.register(
     "Error during upload: {message}" : "Errorea igotzean: {message}",
     "Error during upload, status code {status}" : "Errore bat gertatu da igotzean, {status} egoera kodea",
     "Unknown error during upload" : "Errore ezezaguna igotzean",
-    "Filter filenames…" : "Iragazi fitxategi-izenak...",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\" ekintza behar bezala exekutatu da",
     "Views" : "Ikuspegiak",
     "Files settings" : "FItxategien ezarpenak",
     "File cannot be accessed" : "Ezin da fitxategia atzitu",
@@ -170,6 +173,28 @@ OC.L10N.register(
     "Copy to clipboard" : "Kopiatu arbelera",
     "Use this address to access your Files via WebDAV" : "Erabili helbide hau WebDAV bidez zure fitxategietara sartzeko",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "2FA gaitu baduzu, aplikazioaren pasahitz berria sortu eta erabili behar duzu hemen klik eginez.",
+    "Keyboard shortcuts" : "Teklatuaren lasterbideak",
+    "Speed up your Files experience with these quick shortcuts." : "Azkartu zure Fitxategi esperientzia lasterbide bizkor hauekin",
+    "Open the actions menu for a file" : "Ireki ekintza menua fitxategi baterako",
+    "Rename a file" : "Fitxategi bat berrizendatu",
+    "Delete a file" : "Fitxategi bat ezabatu",
+    "Favorite or remove a file from favorites" : "Fitxategi bat gustoko bihurtu edo gustoko izateari utzi",
+    "Manage tags for a file" : "Fitxategi baten etiketak kudeatu",
+    "Selection" : "Hautapena",
+    "Select all files" : "Fitxategi guztiak aukeratu",
+    "Deselect all files" : "Fitxategi guztiak desaukeratu",
+    "Select or deselect a file" : "Fitxategi bat aukeratu edo desaukeratu",
+    "Select a range of files" : "Fitxategi-hein bat aukeratu",
+    "Navigation" : "Nabigazioa",
+    "Navigate to the parent folder" : "Nabigatu guraso karpetara",
+    "Navigate to the file above" : "Nabigatu goiko fitxategira",
+    "Navigate to the file below" : "Nabigatu azpiko fitxategira",
+    "Navigate to the file on the left (in grid mode)" : "Nabigatu ezkerreko fitxategira (sareta moduan)",
+    "Navigate to the file on the right (in grid mode)" : "Nabigatu eskuineko fitxategira (sareta moduan)",
+    "View" : "Ikusi",
+    "Toggle the grid view" : "Txandakatu sareta ikuspegia",
+    "Open the sidebar for a file" : "Ireki alboko barra fitxategi baterako",
+    "Show those shortcuts" : "Erakutsi lasterbide horiek",
     "Clipboard is not available" : "Arbela ez dago erabilgarri",
     "WebDAV URL copied to clipboard" : "WebDAV URLa arbelean kopiatu da",
     "Owner" : "Jabea",
@@ -178,7 +203,6 @@ OC.L10N.register(
     "Tags" : "Etiketak",
     "You" : "Zu ",
     "Shared multiple times with different people" : "Hainbat aldiz partekatua pertsona ezberdinekin",
-    "Unable to change the favourite state of the file" : "Ezin da fitxategiaren gogoko egoera aldatu",
     "Error while loading the file data" : "Errorea fitxategiaren datuak kargatzerakoan",
     "Pick a template for {name}" : "Hautatu {name}(r)entzako txantiloia",
     "Create a new file with the selected template" : "Sortu fitxategi berria hautatutako txantiloiarekin",
@@ -291,7 +315,7 @@ OC.L10N.register(
     "All files" : "Fitxategi guztiak",
     "List of your files and folders." : "Zure fitxategi eta karpeten zerrenda.",
     "All folders" : "Karpeta guztiak",
-    "Personal Files" : "Fitxategi pertsonalak",
+    "Personal files" : "Fitxategi pertsonalak",
     "List of your files and folders that are not shared." : "Partekatu ez diren zure fitxategi eta karpeten zerrenda.",
     "No personal files found" : "Ez dago fitxategi pertsonalik",
     "Files that are not shared will show up here." : "Partekatu ez dituzun fitxategiak hemen agertuko dira",
@@ -376,40 +400,27 @@ OC.L10N.register(
     "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "\"{mountPoint}\" kanpoko biltegia betetzear dago ({usedSpacePercent}%).",
     "Your storage is almost full ({usedSpacePercent}%)." : "Zure biltegia betetzear dago ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["\"{filter}\" emaitza","\"{filter}\" emaitza"],
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Esteka zuzena kopiatu da (fitxategi/karpeta honetara sarbidea duten erabiltzaileentzat bakarrik balio du)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Esteka zuzena kopiatu da (fitxategi/karpeta honetara sarbidea dutenentzat bakarrik balio du)",
     "Path" : "Bidea",
     "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
     "Favorited" : "Gogoko gisa markatua",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiatu esteka zuzena (fitxategi/karpeta honetara sarbidea duten erabiltzaileentzat bakarrik balio du)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Kopiatu esteka zuzena (fitxategi/karpeta honetara sarbidea dutenentzat bakarrik balio du)",
     "Upload file" : "Igo fitxategia",
     "Not favorited" : "Ez da gogokoa",
     "An error occurred while trying to update the tags" : "Errore bat gertatu da etiketak eguneratzen saiatzean",
-    "\"remote user\"" : "\"urruneko erabiltzailea\"",
-    "{newName} already exists." : "{newName} badago aurretik.",
-    "\"{segment}\" is not allowed inside a filename." : "«{segment}» ez da onartzen fitxategi-izen baten barruan.",
-    "\"{segment}\" is a forbidden file or folder name." : "«{segment}» debekatutako fitxategi edo karpeta-izen bat da.",
-    "\"{segment}\" is not an allowed filetype." : "«{segment}» fitxategi-mota ez da onartzen.",
-    "Filenames must not end with \"{segment}\"." : "Fitxategi-izenak ez dira «{segment}»(e)rekin amaitu behar.",
-    "Name cannot be empty" : "Izena ezin da hutsik egon",
-    "Another entry with the same name already exists" : "Badago izen hori duen beste sarrera bat",
-    "Could not rename \"{oldName}\", it does not exist any more" : "Ezin izan da \"{oldName}\" berrizendatu, ez da existitzen dagoeneko",
-    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{newName}\" izena \"{dir}\" karpetan dagoeneko erabiltzen da. Mesedez aukeratu beste izen bat.",
-    "Could not rename \"{oldName}\"" : "Ezin izan da \"{oldName}\" berrizendatu ",
     "Storage informations" : "Biltegiaren informazioak",
     "Choose file" : "Aukeratu fitxategia",
     "Go to the previous folder" : "Joan aurreko karpetara",
     "Open the files app settings" : "Ireki Fitxategiak aplikazioaren ezarpenak",
-    "You might not have have permissions to view it, ask the sender to share it" : "Baliteke hura ikusteko baimenik ez izatea; eskatu igorleari partekatzeko",
-    "The files is locked" : "Fixategiak blokeatuta dago",
+    "Unable to change the favourite state of the file" : "Ezin da fitxategiaren gogoko egoera aldatu",
     "Create new templates folder" : "Sortu txantiloi karpeta berria",
     "List of favorites files and folders." : "Fitxategi eta karpeta gogokoen zerrenda.",
-    "Toggle %1$s sublist" : "Txandakatu %1$sazpizerrenda",
+    "Personal Files" : "Fitxategi pertsonalak",
     "Text file" : "Testu-fitxategia",
     "New text file.txt" : "Testu-fitxategi berria.txt",
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Esteka zuzena kopiatu da (fitxategi/karpeta honetara sarbidea dutenentzat bakarrik balio du)",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Kopiatu esteka zuzena (fitxategi/karpeta honetara sarbidea dutenentzat bakarrik balio du)",
     "Favored" : "Mesedetua",
     "Favor" : "Mesedea",
-    "Not favored" : "Mesedetu gabe"
+    "Not favored" : "Mesedetu gabe",
+    "Filter filenames…" : "Iragazi fitxategi-izenak..."
 },
 "nplurals=2; plural=(n != 1);");
