@@ -46,6 +46,12 @@ OC.L10N.register(
     "Failed to authorize" : "Autorisering feilet",
     "Invalid folder path" : "Ugyldig mappebane",
     "Folder not found" : "Mappe ikke funnet",
+    "The file cannot be found" : "Kunne ikke finne filen",
+    "The destination path does not exist: %1$s" : "Fildestinasjonen finnes ikke: %1$s",
+    "Could not get relative path to converted file" : "Kunne ikke hente relativ sti til den konverterte filen",
+    "Favorite files" : "Favorittfiler",
+    "No favorites" : "Ingen favoritter",
+    "More favorites" : "Flere favoritter",
     "Upload (max. %s)" : "Opplasting (maks %s)",
     "Accept" : "Aksepter",
     "Reject" : "Avvis",
@@ -75,8 +81,7 @@ OC.L10N.register(
     "Your have used your space quota and cannot upload files anymore" : "Du har brukt opp plasskvoten og kan ikke laste opp filer lenger",
     "You don’t have permission to upload or create files here" : "Du har ikke tillatelse til å laste opp eller opprette filer her",
     "Favorite" : "Gjør til favoritt",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\"-handling utført",
-    "\"{displayName}\" action failed" : "\"{displayName}\"-handling feilet",
+    "Back" : "Tilbake",
     "Toggle selection for file \"{displayName}\"" : "Veksle valg for fil \"{displayName}\"",
     "Toggle selection for folder \"{displayName}\"" : "Veksle valg for mappe \"{displayName}\"",
     "File is loading" : "Filen lastes inn",
@@ -88,6 +93,7 @@ OC.L10N.register(
     "Another entry with the same name already exists." : "En annen oppføring med samme navnet finnes allerede.",
     "Invalid filename." : "Ugyldig filnavn.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Omdøpte \"{oldName}\" tl \"{newName}\"",
+    "Unknown date" : "Ukjent dato",
     "Pending" : "Venter",
     "Clear filter" : "Tøm filter",
     "Modified" : "Endret",
@@ -102,8 +108,11 @@ OC.L10N.register(
     "(selected)" : "(valgt)",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" feilet på noen elementer",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" massehandling utført",
+    "\"{displayName}\" action failed" : "\"{displayName}\"-handling feilet",
     "{count} selected" : "{count} valgt",
     "List of files and folders." : "Liste over filer og mapper.",
+    "You don’t have permission to upload or create files here." : "Du har ikke tilgang til å laste opp eller opprette filer her.",
+    "You have used your space quota and cannot upload files anymore." : "Du har brukt opp lagringskvoten din og kan ikke laste opp flere filer.",
     "Column headers with buttons are sortable." : "Kolonneoverskrifter med knapper kan sorteres.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Denne listen er ikke fullstendig gjengitt av ytelsesgrunner. Filene gjengis når du navigerer gjennom listen.",
     "File not found" : "Finner ikke filen",
@@ -134,7 +143,6 @@ OC.L10N.register(
     "Cannot transfer ownership of a file or folder you do not own" : "Kan ikke overføre eierskap til en fil eller mappe du ikke eier",
     "Select file or folder to link to" : "Velg fil eller mappe å koble til",
     "Choose {file}" : "Choose {file}",
-    "New" : "Ny",
     "Loading current folder" : "Laster gjeldende mappe",
     "Retry" : "Prøv igjen",
     "No files in here" : "Ingen filer",
@@ -151,7 +159,7 @@ OC.L10N.register(
     "Error during upload: {message}" : "Feil under opplasting: {message}",
     "Error during upload, status code {status}" : "Feil under opplasting, statuskode {status}",
     "Unknown error during upload" : "Ukjent feil under opplasting",
-    "Filter filenames…" : "Filtrer filnavn...",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\"-handling utført",
     "Views" : "Visninger",
     "Files settings" : "Filinnstillinger",
     "File cannot be accessed" : "Filen er ikke tilgjengelig",
@@ -170,6 +178,25 @@ OC.L10N.register(
     "Copy to clipboard" : "Kopiert til utklippstavlen",
     "Use this address to access your Files via WebDAV" : "Bruk denne adressen for tilgang til filene dine via WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Hvis du har aktivert 2FA, må du opprette og bruke et nytt app-passord ved å klikke her.",
+    "Keyboard shortcuts" : "Tastatursnarveier",
+    "Speed up your Files experience with these quick shortcuts." : "Jobb raskere med filer ved å bruke disse hurtigtastene.",
+    "Open the actions menu for a file" : "Åpner handlingsmenyen for en fil",
+    "Rename a file" : "Gi nytt navn til en fil",
+    "Delete a file" : "Slett en fil",
+    "Favorite or remove a file from favorites" : "Legg til og fjern en fil fra Favoritter",
+    "Manage tags for a file" : "Behandle merkelapper for en fil",
+    "Selection" : "Valg",
+    "Select all files" : "Velg alle filer",
+    "Deselect all files" : "Velg ingen filer",
+    "Navigation" : "Navigasjon",
+    "Navigate to the parent folder" : "Gå til overordnet mappe",
+    "Navigate to the file above" : "Gå til filen over",
+    "Navigate to the file below" : "Gå til filen under",
+    "Navigate to the file on the left (in grid mode)" : "Gå til filen til venstre (i rutenettvisning)",
+    "Navigate to the file on the right (in grid mode)" : "Gå til filen til høyre (i rutenettvisning)",
+    "View" : "Vis",
+    "Toggle the grid view" : "Slå på/av rutenettvisning",
+    "Show those shortcuts" : "Vis hurtigtastene",
     "Clipboard is not available" : "Utklippstavlen er ikke tilgjengelig",
     "WebDAV URL copied to clipboard" : "WebDAV-URL kopiert til utklippstavlen",
     "Owner" : "Eier",
@@ -178,7 +205,6 @@ OC.L10N.register(
     "Tags" : "Merkelapper",
     "You" : "Du",
     "Shared multiple times with different people" : "Del flere ganger med forskjellige personer",
-    "Unable to change the favourite state of the file" : "Kan ikke endre favorittstatus til filen",
     "Error while loading the file data" : "Feil ved lasting av fildata",
     "Pick a template for {name}" : "Velg en mal for {name}",
     "Create a new file with the selected template" : "Opprett en ny fil med den valgte malen",
@@ -186,12 +212,12 @@ OC.L10N.register(
     "Blank" : "Tom",
     "Unable to create new file from template" : "Kan ikke opprette ny fil fra malen",
     "Deletion cancelled" : "Sletting avbrutt",
-    "Delete permanently" : "Slett for godt",
-    "Delete and unshare" : "Slett og opphev deling",
     "Leave this share" : "Forlat denne delingen",
     "Leave these shares" : "Forlat disse delingene",
     "Disconnect storage" : "Koble fra lager",
     "Disconnect storages" : "Koble fra lagringer",
+    "Delete permanently" : "Slett for godt",
+    "Delete and unshare" : "Slett og opphev deling",
     "Delete file" : "Slett fil",
     "Delete files" : "Slett filer",
     "Delete folder" : "Slett mappe",
@@ -202,8 +228,8 @@ OC.L10N.register(
     "Confirm deletion" : "Bekreft sletting",
     "Cancel" : "Avbryt",
     "Edit file locally" : "Rediger fil lokalt",
-    "The file should now open locally. If you don't see this happening, make sure that the desktop client is installed on your system." : "Filen skal nå åpnes lokalt. Hvis du ikke ser at dette skjer, må du kontrollere at skrivebordsklienten er installert på systemet.",
-    "Retry local edit" : "Prøv lokal redigering på nytt",
+    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Filen skal nå åpnes på enheten din. Om ikke, vennligst sjekk at du har skrivebordsprogrammet installert.",
+    "Retry and close" : "Prøv igjen og lukk",
     "Edit online" : "Rediger på nett",
     "Failed to redirect to client" : "Kunne ikke omdirigere til klienten",
     "Edit locally" : "Rediger lokalt",
@@ -264,9 +290,17 @@ OC.L10N.register(
     "Files moved successfully" : "Filer ble flyttet",
     "Conflicts resolution skipped" : "Konfliktløsning hoppet over",
     "Upload cancelled" : "Opplasting avbrutt",
+    "Adding the file extension \"{new}\" may render the file unreadable." : "Å legge til filendelsen «{new}» kan føre til at filen ikke kan leses.",
+    "Removing the file extension \"{old}\" may render the file unreadable." : "Å fjerne filendelsen «{old}» kan føre til at filen ikke kan leses.",
+    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Å endre filendelsen fra «{old}» til «{new}» kan føre til at filen ikke kan leses.",
+    "Change file extension" : "Endre filendelse",
+    "Keep {oldextension}" : "Behold {oldextension}",
+    "Use {newextension}" : "Bruk {newextension}",
+    "Remove extension" : "Fjern filendelse",
     "This operation is forbidden" : "Operasjonen er forbudt",
     "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappen er utilgjengelig. Sjekk loggene eller kontakt administrator",
     "Storage is temporarily not available" : "Lagring er midlertidig utilgjengelig",
+    "Unexpected error: {error}" : "Uventet feil: {error}",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} mappe","{folderCount} mapper"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} fil","{fileCount} filer"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fil og {folderCount} mappe","1 fil og {folderCount} mapper"],
@@ -283,7 +317,7 @@ OC.L10N.register(
     "All files" : "Alle filer",
     "List of your files and folders." : "Liste over dine filer og mapper.",
     "All folders" : "Alle mapper",
-    "Personal Files" : "Personlige filer",
+    "Personal files" : "Personlige filer",
     "List of your files and folders that are not shared." : "Liste over dine filer og mapper som ikke er delt.",
     "No personal files found" : "Ingen personlige filer funnet",
     "Files that are not shared will show up here." : "Filer som ikke er delt vil vises her.",
@@ -350,6 +384,7 @@ OC.L10N.register(
     "{dirs} and {files}" : "{dirs} og {files}",
     "_including %n hidden_::_including %n hidden_" : ["Inkludert %n skjult","Inkludert %n skjulte"],
     "_Uploading %n file_::_Uploading %n files_" : ["Laster opp %n fil","Laster opp %n filer"],
+    "New" : "Ny",
     "New file/folder menu" : "Ny fil/mappe-meny",
     "Select file range" : "Velg filutvalg",
     "{used}%" : "{used}%",
@@ -367,40 +402,27 @@ OC.L10N.register(
     "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Den eksterne lagringsplassen \"{mountPoint}\" er nesten full ({usedSpacePercent}%).",
     "Your storage is almost full ({usedSpacePercent}%)." : "Din lagringsplass er nesten full ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["Treffer \"{filter}\"","Treff \"{filter}\""],
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Direktelenke ble kopiert (fungerer bare for brukere som har tilgang til denne filen/mappen)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Direkte lenke ble kopiert (fungerer bare for personer som har tilgang til denne filen / mappen)",
     "Path" : "Sti",
     "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
     "Favorited" : "Favorisert",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Kopier direktelenke (fungerer bare for brukere som har tilgang til denne filen/mappen)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Kopier direkte lenke (fungerer bare for personer som har tilgang til denne filen / mappen)",
     "Upload file" : "Last opp fil",
     "Not favorited" : "Ikke i favoritter",
     "An error occurred while trying to update the tags" : "En feil oppsto under oppdatering av merkelappene",
-    "\"remote user\"" : "\"ekstern bruker\"",
-    "{newName} already exists." : "{newName} finnes allerede.",
-    "\"{segment}\" is not allowed inside a filename." : "\"{segment}\" er ikke tillatt i et filnavn.",
-    "\"{segment}\" is a forbidden file or folder name." : "\"{segment}\" er et forbudt fil- eller mappenavn.",
-    "\"{segment}\" is not an allowed filetype." : "\"{segment}\" er ikke en tillatt filtype.",
-    "Filenames must not end with \"{segment}\"." : "Filnavn må ikke slutte med \"{segment}\".",
-    "Name cannot be empty" : "Navn kan ikke være tom",
-    "Another entry with the same name already exists" : "En annen oppføring med samme navnet finnes allerede",
-    "Could not rename \"{oldName}\", it does not exist any more" : "Kunne ikke omdøpe \"{oldName}\", den finnes ikke lenger",
-    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Navnet \"{newName}\" er allerede brukt i mappen \"{dir}\". Velg et annet navn.",
-    "Could not rename \"{oldName}\"" : "Kunne ikke omdøpe \"{oldName}\"",
     "Storage informations" : "Informasjon om lagring",
     "Choose file" : "Velg fil",
     "Go to the previous folder" : "Gå fil forrige mappe",
     "Open the files app settings" : "Åpne Filer-appens innstillinger",
-    "You might not have have permissions to view it, ask the sender to share it" : "Du har kanskje ikke tillatelse til å se den, be avsenderen om å dele den",
-    "The files is locked" : "Filene er låst",
+    "Unable to change the favourite state of the file" : "Kan ikke endre favorittstatus til filen",
     "Create new templates folder" : "Opprett ny malermappe",
     "List of favorites files and folders." : "Liste over favorittfiler og -mapper.",
-    "Toggle %1$s sublist" : "Veksle %1$s underliste",
+    "Personal Files" : "Personlige filer",
     "Text file" : "Tekstfil",
     "New text file.txt" : "Ny tekstfil.txt",
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Direkte lenke ble kopiert (fungerer bare for personer som har tilgang til denne filen / mappen)",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Kopier direkte lenke (fungerer bare for personer som har tilgang til denne filen / mappen)",
     "Favored" : "Favorittlagt",
     "Favor" : "Favoritt",
-    "Not favored" : "Ikke favorittlagt"
+    "Not favored" : "Ikke favorittlagt",
+    "Filter filenames…" : "Filtrer filnavn..."
 },
 "nplurals=2; plural=(n != 1);");
