@@ -46,6 +46,14 @@ OC.L10N.register(
     "Failed to authorize" : "Falha ao autorizar",
     "Invalid folder path" : "Caminho de pasta inválido",
     "Folder not found" : "Pasta não encontrada",
+    "The file cannot be found" : "O arquivo não pôde ser encontrado",
+    "The destination path does not exist: %1$s" : "O caminho de destino não existe: %1$s",
+    "You do not have permission to create a file at the specified location" : "VocÊ não tem permissão para criar um arquivo no local especificado",
+    "The file could not be converted." : "Esse arquivo não pôde ser convertido.",
+    "Could not get relative path to converted file" : "Não foi possível obter o caminho relativo do arquivo convertido",
+    "Favorite files" : "Arquivos favoritos",
+    "No favorites" : "Sem favoritos",
+    "More favorites" : "Mais favoritos",
     "Upload (max. %s)" : "Envio (max. %s)",
     "Accept" : "Aceitar",
     "Reject" : "Rejeitar",
@@ -75,8 +83,7 @@ OC.L10N.register(
     "Your have used your space quota and cannot upload files anymore" : "Você usou sua cota de espaço e não pode mais fazer upload de arquivos",
     "You don’t have permission to upload or create files here" : "Você não tem permissão para enviar ou criar arquivos aqui",
     "Favorite" : "Favorito",
-    "\"{displayName}\" action executed successfully" : "Ação \"{displayName}\" executada com sucesso",
-    "\"{displayName}\" action failed" : "A ação \"{displayName}\" falhou",
+    "Back" : "Voltar",
     "Toggle selection for file \"{displayName}\"" : "Alternar seleção do arquivo \"{displayName}\"",
     "Toggle selection for folder \"{displayName}\"" : "Alternar seleção da pasta \"{displayName}\"",
     "File is loading" : "O arquivo está carregando",
@@ -88,6 +95,7 @@ OC.L10N.register(
     "Another entry with the same name already exists." : "Outra entrada com o mesmo nome já existe.",
     "Invalid filename." : "Nome de arquivo inválido.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Renomeado de \"{oldName}\" para \"{newName}\"",
+    "Unknown date" : "Data desconhecida",
     "Pending" : "Pendente",
     "Clear filter" : "Limpar filtro",
     "Modified" : "Modificado",
@@ -102,8 +110,11 @@ OC.L10N.register(
     "(selected)" : "(selecionado)",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" falhou em alguns elementos",
     "\"{displayName}\" batch action executed successfully" : "Ação em lote \"{displayName}\" executada com sucesso",
+    "\"{displayName}\" action failed" : "A ação \"{displayName}\" falhou",
     "{count} selected" : "{count} selecionados",
     "List of files and folders." : "Lista de arquivos e pastas.",
+    "You don’t have permission to upload or create files here." : "Você não tem permissão para enviar ou criar arquivos aqui.",
+    "You have used your space quota and cannot upload files anymore." : "Você usou sua cota de espaço e não pode mais fazer upload de arquivos.",
     "Column headers with buttons are sortable." : "Os cabeçalhos das colunas com botões são classificáveis.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Essa lista não é totalmente renderizada por motivos de desempenho. Os arquivos serão renderizados conforme você navega pela lista.",
     "File not found" : "Arquivo não encontrado",
@@ -134,7 +145,6 @@ OC.L10N.register(
     "Cannot transfer ownership of a file or folder you do not own" : "Não é possível transferir a propriedade de um arquivo ou pasta que você não possui",
     "Select file or folder to link to" : "Selecione o arquivo ou pasta para vincular",
     "Choose {file}" : "Escolher {file}",
-    "New" : "Novo",
     "Loading current folder" : "Carregando a pasta atual",
     "Retry" : "Tentar novamente",
     "No files in here" : "Nenhum arquivo aqui",
@@ -151,7 +161,7 @@ OC.L10N.register(
     "Error during upload: {message}" : "Erro durante o upload: {message}",
     "Error during upload, status code {status}" : "Erro durante o upload, código de status {status}",
     "Unknown error during upload" : "Erro desconhecido durante o upload",
-    "Filter filenames…" : "Filtrar nomes de arquivos...",
+    "\"{displayName}\" action executed successfully" : "Ação \"{displayName}\" executada com sucesso",
     "Views" : "Visualizações",
     "Files settings" : "Configurações de arquivos",
     "File cannot be accessed" : "File cannot be accessed",
@@ -170,6 +180,28 @@ OC.L10N.register(
     "Copy to clipboard" : "Copiar para área de transferência",
     "Use this address to access your Files via WebDAV" : "Use este endereço para acessar seus Arquivos via WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "If you have enabled 2FA, you must create and use a new app password by clicking here.",
+    "Keyboard shortcuts" : "Atalhos do teclado",
+    "Speed up your Files experience with these quick shortcuts." : "Acelere sua experiência com os Arquivos com estes atalhos",
+    "Open the actions menu for a file" : "Abrir menu de ações para arquivo",
+    "Rename a file" : "Renomear arquivo",
+    "Delete a file" : "Remover um arquivo",
+    "Favorite or remove a file from favorites" : "Favoritar ou remover arquivo dos favoritos",
+    "Manage tags for a file" : "Gerenciar etiquetas para arquivo",
+    "Selection" : "Seleção",
+    "Select all files" : "Selecionar todos os arquivos",
+    "Deselect all files" : "Desselecionar todos os arquivos",
+    "Select or deselect a file" : "Selecionar ou desselecionar um arquivo",
+    "Select a range of files" : "Selecionar múltiplos arquivos",
+    "Navigation" : "Navegação",
+    "Navigate to the parent folder" : "Navegar para o diretório pai",
+    "Navigate to the file above" : "Navegar para o arquivo acima",
+    "Navigate to the file below" : "Navegar para o arquivo abaixo",
+    "Navigate to the file on the left (in grid mode)" : "Navegar para o arquivo na esquerda (no modo grade)",
+    "Navigate to the file on the right (in grid mode)" : "Navegar para o arquivo na direita (no modo grade)",
+    "View" : "Visualizar",
+    "Toggle the grid view" : "Ativar/Desativar modo grade",
+    "Open the sidebar for a file" : "Abrir barra lateral para um arquivo",
+    "Show those shortcuts" : "Mostrar estes atalhos",
     "Clipboard is not available" : "A área de transferência não está disponível",
     "WebDAV URL copied to clipboard" : "URL do WebDAV copiado para a área de transferência",
     "Owner" : "Proprietário",
@@ -178,20 +210,35 @@ OC.L10N.register(
     "Tags" : "Etiquetas",
     "You" : "Você",
     "Shared multiple times with different people" : "Compartilhado várias vezes com pessoas diferentes",
-    "Unable to change the favourite state of the file" : "Não foi possível alterar o estado favorito do arquivo",
+    "Unable to change the favorite state of the file" : "Impossível mudar estado de favorito do arquivo",
     "Error while loading the file data" : "Erro ao carregar os dados do arquivo",
     "Pick a template for {name}" : "Escolha um modelo para {name}",
     "Create a new file with the selected template" : "Crie um novo arquivo com o modelo selecionado",
     "Creating file" : "Criando arquivo",
     "Blank" : "Em branco",
     "Unable to create new file from template" : "Incapaz de criar novo arquivo a partir do modelo",
+    "Save as {displayName}" : "Salvar como {displayName}",
+    "Save as …" : "Salvar como ...",
+    "Converting files…" : "Convertendo arquivos...",
+    "Failed to convert files: {message}" : "Falha ao converter arquivos: {message}",
+    "All files failed to be converted" : "Todos os arquivos falharam na conversão",
+    "One file could not be converted: {message}" : "Um arquivo não pôde ser convertido: {message}",
+    "One file could not be converted" : "Um arquivo não pôde ser convertido",
+    "{count} files could not be converted" : "{count} arquivos não puderam ser convertidos",
+    "{count} files successfully converted" : "{count} arquivos convertidos com sucesso",
+    "Files successfully converted" : "Arquivos convertidos com sucesso",
+    "Failed to convert files" : "Falha ao converter arquivos",
+    "Converting file…" : "Convertendo arquivo...",
+    "File successfully converted" : "Arquivo convertido com sucesso",
+    "Failed to convert file: {message}" : "Falha ao converter arquivo: {message}",
+    "Failed to convert file" : "Falha ao converter arquivo",
     "Deletion cancelled" : "Operação de exclusão cancelada",
-    "Delete permanently" : "Remover permanentemente",
-    "Delete and unshare" : "Excluir e descompartilhar",
     "Leave this share" : "Deixe esses compartilhamentos",
     "Leave these shares" : "Deixe esses compartilhamentos",
     "Disconnect storage" : "Desconectar armazenamento",
     "Disconnect storages" : "Desconectar armazenamentos",
+    "Delete permanently" : "Remover permanentemente",
+    "Delete and unshare" : "Excluir e descompartilhar",
     "Delete file" : "Deletar arquivo",
     "Delete files" : "Deletar arquivos",
     "Delete folder" : "Excluir pasta",
@@ -202,8 +249,8 @@ OC.L10N.register(
     "Confirm deletion" : "Confirmar exclusão",
     "Cancel" : "Cancelar",
     "Edit file locally" : "Editar arquivo localmente",
-    "The file should now open locally. If you don't see this happening, make sure that the desktop client is installed on your system." : "O arquivo agora deve abrir localmente. Se isso não acontecer, certifique-se de que o cliente de desktop esteja instalado em seu sistema.",
-    "Retry local edit" : "Tentar novamente a edição local",
+    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "O arquivo agora deve abrir no seu dispositivo. Caso contrário, verifique se você tem o aplicativo para desktop instalado.",
+    "Retry and close" : "Tente novamente e feche",
     "Edit online" : "Editar on-line",
     "Failed to redirect to client" : "Falha ao redirecionar para o cliente",
     "Edit locally" : "Editar localmente",
@@ -264,6 +311,13 @@ OC.L10N.register(
     "Files moved successfully" : "Arquivos movidos com sucesso",
     "Conflicts resolution skipped" : "Resolução de conflitos ignorada",
     "Upload cancelled" : "Carregamento cancelado",
+    "Adding the file extension \"{new}\" may render the file unreadable." : "Adicionar a extensão de arquivo \"{new}\" pode tornar o arquivo ilegível.",
+    "Removing the file extension \"{old}\" may render the file unreadable." : "Remover a extensão de arquivo \"{old}\" pode tornar o arquivo ilegível.",
+    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Alterar a extensão do arquivo de \"{old}\" para \"{new}\" pode tornar o arquivo ilegível.",
+    "Change file extension" : "Alterar extensão de arquivo",
+    "Keep {oldextension}" : "Manter {oldextension}",
+    "Use {newextension}" : "Usar {newextension}",
+    "Remove extension" : "Remover extensão",
     "This operation is forbidden" : "Esta operação é proibida",
     "This directory is unavailable, please check the logs or contact the administrator" : "Este diretório não está disponível, por favor verifique os logs ou contacte o administrador",
     "Storage is temporarily not available" : "O armazenamento está temporariamente indisponível",
@@ -284,7 +338,7 @@ OC.L10N.register(
     "All files" : "Todos os arquivos",
     "List of your files and folders." : "Lista de seus arquivos e pastas.",
     "All folders" : "Todas as pastas",
-    "Personal Files" : "Arquivos pessoais",
+    "Personal files" : "Arquivos pessoais",
     "List of your files and folders that are not shared." : "Lista dos seus arquivos e pastas que não estão compartilhados.",
     "No personal files found" : "Nenhum arquivo pessoal encontrado",
     "Files that are not shared will show up here." : "Arquivos que não estão compartilhados aparecerão aqui.",
@@ -351,6 +405,7 @@ OC.L10N.register(
     "{dirs} and {files}" : "{dirs} e {files}",
     "_including %n hidden_::_including %n hidden_" : ["incluindo %n oculto","incluindo %n ocultos","incluindo %n ocultos"],
     "_Uploading %n file_::_Uploading %n files_" : ["Enviando %n arquivo","Enviando %n arquivos","Enviando %n arquivos"],
+    "New" : "Novo",
     "New file/folder menu" : "Novo menu de arquivo/pasta",
     "Select file range" : "Selecionar o intervalo de arquivos",
     "{used}%" : "{used}%",
@@ -368,40 +423,27 @@ OC.L10N.register(
     "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "O armazenamento externo \"{mountPoint}\" está quase cheio ({usedSpacePercent}%).",
     "Your storage is almost full ({usedSpacePercent}%)." : "Seu armazenamento está quase cheio ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["coincide \"{filter}\"","coincide \"{filter}\"","coincide \"{filter}\""],
-    "Direct link was copied (only works for users who have access to this file/folder)" : "O link direto foi copiado (funciona apenas para usuários que têm acesso a este arquivo/pasta)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Link direto foi copiado (funciona apenas para pessoas que têm acesso a este arquivo/pasta)",
     "Path" : "Caminho",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
     "Favorited" : "Favoritado",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar link direto (funciona apenas para usuários que tem acesso a este arquivo/pasta)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Copiar link direto (funciona apenas para pessoas que têm acesso a este arquivo/pasta)",
     "Upload file" : "Enviar arquivo",
     "Not favorited" : "Sem favoritos",
     "An error occurred while trying to update the tags" : "Ocorreu um erro enquanto tentava atualizar as etiquetas",
-    "\"remote user\"" : "\"usuário remoto\"",
-    "{newName} already exists." : "{newName} já existe.",
-    "\"{segment}\" is not allowed inside a filename." : "\"{segment}\" não é permitido dentro de um nome de arquivo.",
-    "\"{segment}\" is a forbidden file or folder name." : "\"{segment}\" é um nome de arquivo ou pasta proibido.",
-    "\"{segment}\" is not an allowed filetype." : "\"{segment}\" não é um tipo de arquivo permitido.",
-    "Filenames must not end with \"{segment}\"." : "Os nomes de arquivos não devem terminar com \"{segment}\".",
-    "Name cannot be empty" : "O nome não pode ficar em branco",
-    "Another entry with the same name already exists" : "Já existe outra entrada com o mesmo nome",
-    "Could not rename \"{oldName}\", it does not exist any more" : "Não foi possível renomear \"{oldName}\", ele não existe mais",
-    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome \"{newName}\" já é utilizado na pasta \"{dir}\". Escolha um nome diferente.",
-    "Could not rename \"{oldName}\"" : "Não foi possível renomear \"{oldName}\"",
     "Storage informations" : "Informações de armazenamento",
     "Choose file" : "Escolher arquivo",
     "Go to the previous folder" : "Ir para a pasta anterior",
     "Open the files app settings" : "Abra as configurações do aplicativo de arquivos",
-    "You might not have have permissions to view it, ask the sender to share it" : "You might not have have permissions to view it, ask the sender to share it",
-    "The files is locked" : "Os arquivos estão bloqueados",
+    "Unable to change the favourite state of the file" : "Não foi possível alterar o estado favorito do arquivo",
     "Create new templates folder" : "Criar nova pasta de modelos",
     "List of favorites files and folders." : "Lista de arquivos e pastas favoritos.",
-    "Toggle %1$s sublist" : "Alternar a sublista %1$s",
+    "Personal Files" : "Arquivos pessoais",
     "Text file" : "Arquivo texto",
     "New text file.txt" : "Novo arquivo de texto arquivo.txt",
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Link direto foi copiado (funciona apenas para pessoas que têm acesso a este arquivo/pasta)",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Copiar link direto (funciona apenas para pessoas que têm acesso a este arquivo/pasta)",
     "Favored" : "Favoritado",
     "Favor" : "Favor",
-    "Not favored" : "Não favoritado"
+    "Not favored" : "Não favoritado",
+    "Filter filenames…" : "Filtrar nomes de arquivos..."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
