@@ -12,17 +12,29 @@ OC.L10N.register(
     "Password policy" : "Požadavky na hesla",
     "Allows admins to configure a password policy" : "Umožňuje správcům nastavovat pravidla pro hesla",
     "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Umožnit správci definovat určité požadavky na heslo – např. vynutit minimální délku",
-    "Minimum password length" : "Minimální délka hesla",
-    "User password history" : "Historie hesel uživatele",
-    "Number of days until user password expires" : "Počet dní do skončení platnosti hesla uživatele",
+    "General password policies" : "Obecné zásady pro hesla",
+    "Add policy set" : "Přidat sadu zásad",
+    "Login policies" : "Zásady přihlašování",
+    "Password history size" : "Hloubka historie hesla",
+    "Number of passwords to keep (securely hashed) to prevent users from reusing previously used passwords." : "Počet hesel které si pamatovat (bezpečně coby jen jejich otisky) a bránit tak uživatelům v opětovném použití dřívějších hesel.",
+    "Maximum login attempts" : "Nejvyšší umožněný počet pokusů o přihlášení",
     "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Počet pokusů o přihlášení před zablokováním uživatelského účtu (0 bez omezení)",
-    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Toto nastavení je určeno k ochraně napadených účtů. Zablokované účty je nutné manuálně zapnout v administraci. Útočníkům snažícím se uhádnout hesla uživatelských účtů bude jejich IP adresa zablokována nezávisle na tomto nastavení.",
+    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Toto nastavení je určeno k ochraně napadených účtů. Zablokované účty je nutné ručně zapnout ve správě. Útočníkům snažícím se uhádnout hesla uživatelských účtů bude jejich IP adresa zablokována nezávisle na tomto nastavení.",
+    "Number of days until user password expires" : "Počet dní do skončení platnosti hesla uživatele",
+    "Password expiration" : "Skončení platnosti hesla",
+    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "Varování: zapnutí omezení délky platnosti hesla je v současnosti už považováno za bezpečnostní riziko a to hned několika bezpečnostními agenturami.",
+    "Remove policy" : "Odebrat zásadu",
+    "Minimum password length" : "Minimální délka hesla",
     "Forbid common passwords" : "Zakázat běžná hesla",
     "Enforce upper and lower case characters" : "Vyžadovat VELKÁ a malá písmena",
     "Enforce numeric characters" : "Vyžadovat čísla",
     "Enforce special characters" : "Vyžadovat speciální znaky",
     "Check password against the list of breached passwords from haveibeenpwned.com" : "Zkontrolovat heslo vůči seznamu prolomených hesel na haveibeenpwned.com",
     "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Tato kontrola vytvoří otisk (hash) hesla a pošle prvních 5 znaků tohoto otisku na aplikační program. rozhraní (API) služby haveibeenpwned.com pro získání seznamu všech otisků, které začínají na tento. Pak zkontroluje na instanci Nextcloud, zda se ve výsledné sadě vyskytuje otisk daného hesla.",
+    "Account password policies" : "Zásady ohledně hesel k účtům",
+    "Share password policies" : "Zásady ohledně hesel ke sdílením",
+    "User password history" : "Historie hesel uživatele",
+    "Please note, that this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Mějte na paměti, že toto nastavení je určeno k ochraně napadených účtů. Zablokované účty je nutné manuálně zapnout v administraci. Útočníkům snažícím se uhádnout hesla uživatelských účtů bude jejich IP adresa zablokována nezávisle na tomto nastavení.",
     "Unknown error" : "Neznámá chyba",
     "Minimal length has to be a non negative number" : "Je třeba, aby nejkratší přípustná délka nebylo záporné číslo",
     "History size has to be a non negative number" : "Je třeba, aby hloubka historie nebylo záporné číslo",
