@@ -5,6 +5,7 @@ OC.L10N.register(
     "-" : "-",
     "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Центар за приватност приказује где су Ваши подаци ускладиштени и ко може да им приступ, или зато што сте их Ви поделили са њима, или зато што су администратори.",
     "Administrators" : "Администратори",
+    "The following accounts are designated administrators and may potentially have access to your data through system storage or backups. However, they do not have easy access to your data via the web interface or client applications." : "Следећи налози су одређени за администраторе и потенцијално могу да имају приступ вашим подацима кроз системско складиште или резервне копије. Међутим, они немају једноставни приступ вашим подацима кроз веб интерфејс или клијентске апликације.",
     "Loading administrators …" : "Учитавају се адмнистратори",
     "Remove external {propertyName} admin" : "Уклони спољног {propertyName} админа",
     "Add external admin" : "Додај спољног администратора",
@@ -300,16 +301,6 @@ OC.L10N.register(
     "Mayotte" : "Мајот",
     "South Africa" : "Јужноафричка република",
     "Zambia" : "Замбија",
-    "Zimbabwe" : "Зимбабве",
-    "Adapt encryption" : "Прилагоди шифрирање",
-    "The admin has not selected the location of the server yet." : "Админ још увек није поставио локацију сервера.",
-    "You don't have any shares with individual users." : "Немате дељења са појединачним корисницима.",
-    "Your %s account" : "Ваш %s налог",
-    "Defining basic rights for people to control their own data in the internet age" : "Дефинише основна права људи да контролишу сопствене податке у доба интернета",
-    "People you shared with" : "Људи са којима делите",
-    "Read the privacy policy." : "Прочитајте политику приватности.",
-    "You don" : "Немате",
-    "Loading people you" : "Учитавају се људи које ",
-    "People you" : "Људи које"
+    "Zimbabwe" : "Зимбабве"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
