@@ -103,8 +103,14 @@ OC.L10N.register(
     "_{count} notification_::_{count} notifications_" : ["{count} upozornění","{count} upozornění","{count} upozornění","{count} upozornění"],
     "No" : "Ne",
     "Yes" : "Ano",
+    "Federated user" : "Federovaný uživatel",
+    "user@your-nextcloud.org" : "uzivatel@vas-nextcloud.org",
     "Create share" : "Vytvořit sdílení",
+    "The remote URL must include the user." : "Je třeba, aby vzdálená URL obsahovala uživatele.",
+    "Invalid remote URL." : "Neplatná vzdálená URL.",
     "Failed to add the public link to your Nextcloud" : "Nepodařilo se přidání veřejného odkazu do Nextcloud",
+    "Direct link copied to clipboard" : "Přímý odkaz zkopírován do schránky",
+    "Please copy the link manually:" : "Zkopírujte odkaz ručně:",
     "Custom date range" : "Uživatelsky určené datumové rozmezí",
     "Pick start date" : "Vybrat datum začátku",
     "Pick end date" : "Vybrat datum konce",
@@ -174,7 +180,7 @@ OC.L10N.register(
     "Schedule work & meetings, synced with all your devices." : "Plánujte si práci a schůzky – synchronizováno napříč všemi vašimi zařízeními.",
     "Keep your colleagues and friends in one place without leaking their private info." : "Uchovávejte si údaje svých kolegů a přátel na jednom místě, aniž by k jejim osobním údajům získal přístup někdo jiný.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Jednoduchý e-mailový klient, propojený s aplikacemi Soubory, Kontakty a Kalendář.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatování, videohovory, sdílení obrazovky, schůze na dálku a webové konference – ve webovém prohlížeči a mobilních aplikacích.",
+    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatování, videohovory, sdílení obrazovky, schůze na dálku a webové konference – ve webovém prohlížeči a mobilních aplikacích.",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Dokumenty, tabulky a prezentace pro spolupráci, založené na Collabora Online.",
     "Distraction free note taking app." : "Aplikace pro psaní poznámek bez rozptylování.",
     "Settings menu" : "Nabídka nastavení",
@@ -200,11 +206,6 @@ OC.L10N.register(
     "Back" : "Zpět",
     "Login form is disabled." : "Formulář pro přihlášení je vypnut",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Přihlašovací formulář je v Nextcloud vypnutý. Použijte jinou možnost přihlášení nebo se obraťte na svého správce.",
-    "Edit Profile" : "Upravit profil",
-    "The headline and about sections will show up here" : "Nadpis a sekce o uživatelích se zobrazí zde",
-    "You have not added any info yet" : "Zatím jste nezadali žádné informace",
-    "{user} has not added any info yet" : "{user} uživatel zatím nezadal žádné informace",
-    "Error opening the user status modal, try hard refreshing the page" : "Chyba při otevírání dialogu stavu uživatele, pokus o opětovné načtení stránky",
     "More actions" : "Další akce",
     "This browser is not supported" : "Tento prohlížeč není podporován",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Vámi využívaný webový prohlížeč není podporován. Přejděte na novější verzi nebo na nějaký podporovaný.",
@@ -262,20 +263,18 @@ OC.L10N.register(
     "Rename" : "Přejmenovat",
     "Collaborative tags" : "Štítky pro spolupráci",
     "No tags found" : "Nenalezeny žádné štítky",
+    "Clipboard not available, please copy manually" : "Schránka není k dispozici – zkopírujte ručně",
     "Personal" : "Osobní",
     "Accounts" : "Účty",
     "Admin" : "Správa",
     "Help" : "Nápověda",
     "Access forbidden" : "Přístup zakázán",
-    "Profile not found" : "Profil nenalezen",
-    "The profile does not exist." : "Profil neexistuje.",
-    "Back to %s" : "Zpět na %s",
     "Page not found" : "Stránka nenalezena",
     "The page could not be found on the server or you may not be allowed to view it." : "Stránku se na serveru nepodařilo nalézt nebo nemáte oprávnění ji zobrazit.",
+    "Back to %s" : "Zpět na %s",
     "Too many requests" : "Příliš mnoho požadavků",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Z vaší sítě bylo příliš mnoho požadavků. Zkuste to později nebo (pokud je toto chyba) se obraťte na svého správce.",
     "Error" : "Chyba",
-    "Previous" : "Předchozí",
     "Internal Server Error" : "Vnitřní chyba serveru",
     "The server was unable to complete your request." : "Server nemohl dokončit váš požadavek.",
     "If this happens again, please send the technical details below to the server administrator." : "Pokud se toto stane znovu, pošlete níže uvedené technické podrobnosti správci serveru.",
@@ -293,7 +292,9 @@ OC.L10N.register(
     "Security warning" : "Varování ohledně zabezpečení",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Váš adresář data a soubory jsou přístupné z Internetu, protože soubor .htaccess nefunguje.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informace o tom, jak správně nastavit svůj server, naleznete v <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaci</a>.",
-    "Create an <strong>admin account</strong>" : "Vytvořit <strong>účet správce</strong>",
+    "<strong>Create an admin account</strong>" : "</strong>Vytvořit účet správce</strong>",
+    "New admin account name" : "Název účtu nového správce",
+    "New admin password" : "Heslo nového správce",
     "Show password" : "Zobrazit heslo",
     "Toggle password visibility" : "Přepnout viditelnost hesla",
     "Storage & database" : "Úložiště a databáze",
@@ -335,6 +336,7 @@ OC.L10N.register(
     "Account connected" : "Účet připojen",
     "Your client should now be connected!" : "Váš klient by nyní měl být připojen!",
     "You can close this window." : "Toto okno je možné zavřít.",
+    "Previous" : "Předchozí",
     "This share is password-protected" : "Toto sdílení je chráněno heslem",
     "The password is wrong or expired. Please try again or request a new one." : "Nesprávné heslo nebo jeho platnost skončila. Prosím zkuste to znovu nebo si zažádejte o nové.",
     "Please type in your email address to request a temporary password" : "Pokud si chcete požádat o dočasné heslo, zadejte svou e-mailovou adresu",
@@ -373,37 +375,17 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Tato instance %s se právě nachází v režimu údržby a ta může chvíli trvat.",
     "This page will refresh itself when the instance is available again." : "Tato stránka se automaticky znovu načte, jakmile bude tato instance opět dostupná.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Pokud se tato zpráva objevuje trvale nebo nečekaně, obraťte se na správce systému.",
-    "The user limit of this instance is reached." : "Bylo dosaženo limitu počtu uživatelů této instance.",
-    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Pokud chcete zvýšit limit počtu uživatelů, zadejte klíč svého předplatného. To vám zpřístupní také veškeré další přínosy, které Nextcloud Enterprise poskytuje a je velmi doporučováno pro provozování ve firmách.",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Váš webový server ještě není správně nastaven, pro umožnění synchronizace souborů, rozhraní WebDAV pravděpodobně není funkční.",
-    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Tento webový server není správně nastaven pro rozpoznání „{url}“. Další informace jsou k dispozici v {linkstart}dokumentaci ↗{linkend}.",
-    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Tento webový server není správně nastaven pro rozpoznání „{url}“. To nejspíše souvisí s nastavením webového serveru, které nebylo upraveno tak, aby jej dovedlo přímo do této složky. Porovnejte svou konfiguraci s dodávanými rewrite pravidly v „.htaccess“ pro Apache nebo těm poskytnutým v dokumentaci pro Nginx na této {linkstart}stránce s dokumentací ↗{linkend}. U Nginx jsou to obvykle řádky začínající na „location ~“, které potřebují úpravu.",
-    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Váš webový server není správně nastaven k doručování .woff2 souborů. To je obvykle chyba v nastavení Nginx. Nextcloud 15 také potřebuje úpravu k doručování .woff2 souborů. Porovnejte své nastavení Nginx s doporučeným nastavením v naší {linkstart}dokumentaci ↗{linkend}.",
-    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "K vámi využívané instanci sice přistupujete přes zabezpečené připojení, nicméně tato vytváří nezabezpečené URL adresy. To s nejvyšší pravděpodobností znamená, že se nacházíte za reverzní proxy a proměnné v jejím nastavení, ohledně procesu přepisování, nejsou správně nastavené. Přečtete si tomu věnovanou {linkstart}stránku v dokumentaci ↗{linkend}.",
-    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Váš datový adresář a soubory jsou pravděpodobně přístupné z Internetu. Soubor .htaccess nefunguje. Je důrazně doporučeno nastavit váš webový server tak, aby  tento adresář už nebyl dostupný z Internetu, nebo byl přesunut mimo prostor, zpřístupňovaný webovým serverem.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP hlavička „{header}“ není nastavena ve shodě s „{expected}“. To značí možné ohrožení bezpečnosti a soukromí a je doporučeno toto nastavení upravit.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP hlavička „{header}“ není nastavena ve shodě s „{expected}“. To značí možné ohrožení bezpečnosti a soukromí a je doporučeno toto nastavení upravit.",
-    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP hlavička „{header}“ neobsahuje „{expected}“. To značí možné ohrožení bezpečnosti a soukromí a je doporučeno toto nastavení upravit.",
-    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "HTTP hlavička „{header}“ není nastavena na „{val1}“, „{val2}“, „{val3}“, „{val4}“ nebo „{val5}“. To může odhalovat referer informaci. Viz {linkstart}doporučení W3C ↗{linkend}.",
-    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "HTTP hlavička „Strict-Transport-Security“ není nastavena na přinejmenším „{seconds}“ sekund. Pro lepší zabezpečení je doporučeno zapnout HSTS, jak je popsáno v {linkstart}tipech pro zabezpečení ↗{linkend}.",
-    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Přistupujete přes přes nezabezpečený HTTP protokol. Důrazně doporučujeme nastavit svůj server tak, aby namísto toho vyžadoval HTTPS, jak je popsáno v {linkstart}tipech ohledně zabezpečení ↗{linkend}. Bez šifrovaného spojení nebudou k dispozici některé důležité funkce, jako např. „zkopírovat do schránky“ nebo tzv. „service workers“!",
     "Currently open" : "Nyní otevřeno",
-    "Wrong username or password." : "Nesprávné uživatelské jméno nebo heslo.",
-    "User disabled" : "Uživatelský účet znepřístupněn",
     "Login with username or email" : "Přihlásit se uživatelským jménem nebo e-mailem",
     "Login with username" : "Přihlásit se uživatelským jménem",
-    "Username or email" : "Uživ. jméno nebo e-mail",
-    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "Pokud tento účet existuje, byla na jeho e-mailovou adresu odeslána zpráva s pokyny pro znovunastavení hesla. Pokud jste ji neobdrželi, podívejte se také do složek s nevyžádanou poštou (spam) a/nebo požádejte svého místního správce o pomoc.",
-    "Apps and Settings" : "Aplikace a natavení",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatování, videohovory, sdílení obrazovky, schůze na dálku a webové konference – ve webovém prohlížeči a mobilních aplikacích.",
+    "Edit Profile" : "Upravit profil",
+    "The headline and about sections will show up here" : "Nadpis a sekce o uživatelích se zobrazí zde",
+    "You have not added any info yet" : "Zatím jste nezadali žádné informace",
+    "{user} has not added any info yet" : "{user} uživatel zatím nezadal žádné informace",
+    "Error opening the user status modal, try hard refreshing the page" : "Chyba při otevírání dialogu stavu uživatele, pokus o opětovné načtení stránky",
     "Error loading message template: {error}" : "Chyba při načítání šablony zprávy: {error}",
-    "Users" : "Uživatelé",
-    "Username" : "Uživatelské jméno",
-    "Database user" : "Uživatel databáze",
-    "This action requires you to confirm your password" : "Tato akce vyžaduje zadání vašeho hesla",
-    "Confirm your password" : "Potvrdit heslo",
-    "Confirm" : "Potvrdit",
-    "App token" : "Token aplikace",
-    "Alternative log in using app token" : "Alternativní přihlášení pomocí tokenu aplikace",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Použijte aktualizační příkazový řádek, protože máte velkou instanci s více než 50 uživateli."
+    "Profile not found" : "Profil nenalezen",
+    "The profile does not exist." : "Profil neexistuje."
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
