@@ -54,8 +54,8 @@ OC.L10N.register(
     "unknown text" : "ຂໍ້ຄວາມທີ່ບໍ່ຮູ້",
     "Hello world!" : "ສະບາຍດີ",
     "sunny" : "ມີເເດດ",
-    "Hello {name}, the weather is {weather}" : "ສະບາຍດີ {ຊື່}, ອາກາດແມ່ນ {weather}",
-    "Hello {name}" : "ສະບາຍດີ {ຊື່}",
+    "Hello {name}, the weather is {weather}" : "ສະບາຍດີ {name}, ອາກາດແມ່ນ {weather}",
+    "Hello {name}" : "ສະບາຍດີ {name}",
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>ເຫຼົ່ານີ້ແມ່ນຜົນການຊອກຫາຂອງທ່ານ<script> alert(1)</script></strong>",
     "new" : "ໃໝ່",
     "_download %n file_::_download %n files_" : ["ຟາຍ%n ດາວ ໂຫລດ"],
@@ -100,7 +100,6 @@ OC.L10N.register(
     "Schedule work & meetings, synced with all your devices." : "ຕາຕະລາງການເຮັດວຽກ & ການປະຊຸມ, synced ກັບອຸປະກອນທັງຫມົດຂອງທ່ານ.",
     "Keep your colleagues and friends in one place without leaking their private info." : "ຮັກສາເພື່ອນຮ່ວມງານ ແລະ ຫມູ່ ເພື່ອນ ຂອງ ທ່ານ ໄວ້ ໃນບ່ອນດຽວໂດຍບໍ່ໄດ້ ໃຫ້ຂໍ້ ຄວາມ ສ່ວນ ຕົວ ຂອງ ເຂົາ ເຈົ້າຮົ່ວໄຫຼ .",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "ແອັບອີເມວລວມເຂົ້າກັບ ຟາຍຕ່າງໆ, ເບີຕິດຕໍ່ ແລະ ປະຕິທິນ",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatting, ການໂທວິດີໂອ, screen sharing, ການປະຊຸມອອນໄລນ໌ ແລະ ການປະຊຸມເວັບໄຊ – ໃນເວັບໄຊຂອງທ່ານ ແລະ apps ມືຖື.",
     "Settings menu" : "ການຕັ້ງຄ່າເມນູ",
     "Reset search" : "Reset ຄົ້ນຫາ",
     "Search contacts …" : "ຄົ້ນຫາຕິດຕໍ່ ...",
@@ -113,11 +112,11 @@ OC.L10N.register(
     "Loading more results …" : "ຜົນການດາວໂຫຼດເພີ່ມເຕີມ ...",
     "Search" : "ຄົ້ນຫາ",
     "No results for {query}" : "ບໍ່ມີຜົນສໍາລັບ {query}",
-    "An error occurred while searching for {type}" : "ເກີດຂໍ້ຜິດພາດໃນຂະນະທີ່ຊອກຫາ {ປະເພດ}",
+    "An error occurred while searching for {type}" : "ເກີດຂໍ້ຜິດພາດໃນຂະນະທີ່ຊອກຫາ {type}",
     "Forgot password?" : "ລືມລະຫັດຜ່ານ?",
     "Back" : "ຫຼັງ",
     "Login form is disabled." : "ຮູບແບບLogin ຖືກປິດ.",
-    "Search {types} …" : "ຄົ້ນຫາ {ປະເພດ} ...",
+    "Search {types} …" : "ຄົ້ນຫາ {types} ...",
     "Choose" : "ເລືອກ",
     "Copy" : "ສຳເນົາ",
     "Move" : "ຍ້າຍ",
@@ -187,7 +186,6 @@ OC.L10N.register(
     "Security warning" : "ຄໍາເຕືອນດ້ານຄວາມປອດໄພ",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "ຊອບແວຂໍ້ມູນແລະ ຟາຍ ຂອງ ທ່ານອາດຈະເຂົ້າເຖິງໄດ້ຈາກອິນເຕີເນັດເພາະວ່າຟາຍ .htaccess ບໍ່ໄດ້ຜົນ .",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "ສໍາລັບຂໍ້ມູນວິທີການຕັ້ງຄ່າ server ຂອງທ່ານຢ່າງຖືກຕ້ອງ, ກະລຸນາເບິ່ງ <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">ເອກະສານ</a>",
-    "Create an <strong>admin account</strong>" : "ສ້າງ <strong>ບັນຊີ admin</strong>",
     "Show password" : "ສະແດງລະຫັດຜ່ານ",
     "Storage & database" : "ການເກັບກໍາຂໍ້ມູນ & ຖານຂໍ້ມູນ",
     "Data folder" : "ໂຟນເດີຂໍ້ມູນ",
@@ -254,28 +252,7 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "%sຕົວຢ່າງນີ້ໃນປັດຈຸບັນແມ່ນຢູ່ໃນວິທີການບໍາລຸງຮັກສາ, ຊຶ່ງອາດຈະໃຊ້ ເວລາໃນໄລຍະໜຶ່ງ",
     "This page will refresh itself when the instance is available again." : "ຫນ້ານີ້ຈະ refresh ເມື່ອມີຕົວຢ່າງອີກ.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "ຕິດຕໍ່ຜູ້ບໍລິຫານລະບົບຂອງທ່ານຖ້າຫາກວ່າຂ່າວສານນີ້ຍັຢູ່ ຫຼື ປາກົດໂດຍບໍ່ຄາດຄິດ.",
-    "The user limit of this instance is reached." : "ຮອດກໍານົດ ຈໍາກັດຈໍານວນຜູ້ໃຊ້ແລ້ວ",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "ເວັບເຊີບເວີ ຂອງທ່ານຍັງບໍ່ຖືກຕັ້ງຄ່າຢ່າງຖືກຕ້ອງເພື່ອອະນຸຍາດໃຫ້ຟາຍເອກະສານກົງກັນ, ເພາະວ່າອິນເຕີເຟດ WebDAV ອາດຖືກທໍາລາຍ ",
-    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "ເວັບໄຊຂອງທ່ານບໍ່ໄດ້ຖືກຕິດຕັ້ງຢ່າງຖືກຕ້ອງ  ເພື່ອແກ້ ໄຂ \"{url}\" . ຂໍ້ມູນເພີ່ມເຕີມສາມາດເບິ່ງໄດ້ໃນເອກະສານ {linkstart}↗{linkend}.",
-    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "ເວັບໄຊຂອງທ່ານບໍ່ໄດ້ຕິດຕັ້ງຢ່າງຖືກຕ້ອງ ເພື່ອແກ້ ໄຂ \"{url}\" . ກ່ຽວຂ້ອງກັບການຕັ້ງຄ່າເວັບໄຊທີ່ບໍ່ມີການປັບປຸງເພື່ອສົ່ງໂຟນເດີນີ້ໂດຍກົງ. ກະລຸນາປຽບທຽບການຕັ້ງຄ່າຂອງທ່ານກັບກົດລະບຽບການຂຽນຄືນທີ່ຖືກສົ່ງໃນ \".htaccess\" ສໍາລັບ Apache ຫຼື ທີ່ສະຫນອງໃນເອກະສານສໍາລັບ Nginx ທີ່ມັນເປັນ {linkstart}ຫນ້າເອກະສານ↗{linkend}. ໃນ Nginx ເຫຼົ່ານັ້ນໂດຍປົກກະຕິແລ້ວແມ່ນເລີ່ມຕົ້ນດ້ວຍ \"ສະຖານທີ່ ~\" ທີ່ຕ້ອງການການປັບປຸງ.",
-    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "ເວັບ ໄຊຂອງທ່ານບໍ່ໄດ້ ຕິດຕັ້ງຢ່າງຖືກຕ້ອງເພື່ອສົ່ງຟາຍ ໌.woff2 . ໂດຍປົກກະຕິແລ້ວແມ່ນບັນຫາທີ່ມີການຕັ້ງຄ່າ Nginx. ສໍາລັບ Nextcloud 15 ມັນຈໍາເປັນຕ້ອງມີການປັບຕົວເພື່ອສົ່ງຟາຍ .woff2 ອີກດ້ວຍ. ປຽບທຽບການຕັ້ງຄ່າ Nginx ຂອງທ່ານກັບການຕັ້ງຄ່າທີ່ ແນະນໍາໃນເອກະສານ {linkstart} ຂອງພວກເຮົາ ↗{linkend}.",
-    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "ທ່ານກໍາລັງເຂົ້າເຖິງຕົວຢ່າງຂອງທ່ານ ກ່ຽວກັບການຕິດຕໍ່ທີ່ປອດໄພ , ເຖິງຢ່າງໃດ ກໍ ຕາມ ຕົວຢ່າງຂອງ ທ່ານແມ່ນການສ້າງ URLs ບໍ່ ຫມັ້ນ ຄົງ . ຫມາຍຄວາມວ່າທ່ານຢູ່ເບື້ອງຫຼັງ proxy reverse ແລະ ຕົວປ່ຽນໃນconfig overwrite ບໍ່ຖືກຕ້ອງ. ກະລຸນາອ່ານ {linkstart}ຫນ້າເອກະສານກ່ຽວກັບ↗{linkend}.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "ຫົວຂໍ້ HTTP \"{header}\" ບໍ່ໄດ້ຖືກກໍານົດ \"{expected}\". ນີ້ແມ່ນຄວາມສ່ຽງດ້ານຄວາມປອດໄພ ຫຼື ຄວາມເປັນສ່ວນຕົວທີ່ອາດເປັນໄປໄດ້, ແນະນໍາໃຫ້ປັບການຕັ້ງຄ່ານີ້",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "ຫົວຂໍ້ HTTP \"{header}\" ບໍ່ໄດ້ຖືກກໍານົດ\"{expected}\". ບາງຄຸນລັກສະນະອາດຈະເຮັດວຽກບໍ່ຖືກຕ້ອງ , ແນະນໍາໃຫ້ປັບການຕັ້ງຄ່ານີ້ຕາມທີ່ວາງໄວ້.",
-    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "ຫົວຂໍ້ \"{header}\" HTTP ບໍ່ໄດ້ກໍານົດ \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" ຫຼື \"{val5}\". ສາມາດເຮັດໃຫ້ຂໍ້ມູນ referer ຮົ່ວ. ເບິ່ງຂໍ້ແນະນໍາ {linkstart}W3C ↗{linkend}.",
-    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "ຫົວຂໍ້ \"Strict-Transport-Security\" HTTP ບໍ່ໄດ້ກໍານົດໄວ້ຢ່າງຫນ້ອຍ \"{seconds}\" ວິນາທີ. ສໍາລັບເພີ່ມຄວາມປອດໄພ, ແນະນໍາໃຫ້ເຮັດໃຫ້ HSTS ຕາມທີ່ໄດ້ບັນຍາຍໄວ້ໃນ{linkstart}↗{linkend}ຄໍາແນະນໍາຄວາມປອດໄພ ",
-    "Wrong username or password." : "ຊື່ຜູ້ໃຊ້ ຫຼື ລະຫັດຜ່ານຜິດ.",
-    "User disabled" : "ປິດຊື່ຜູ້ໃຊ້",
-    "Username or email" : "ຊື່ຜູ້ໃຊ້ ຫຼື ອີເມວ",
-    "Error loading message template: {error}" : "ການໂຫຼດຂໍ້ຄວາມຜິດພາດ:  {error}",
-    "Users" : "ຜູ້ໃຊ້",
-    "Username" : "ຊື່ຜູ້ໃຊ້",
-    "Database user" : "ຜູ້ໃຊ້ຖານຂໍ້ມູນ",
-    "This action requires you to confirm your password" : "ການກະທໍານີ້ຮຽກຮ້ອງໃຫ້ທ່ານເພື່ອຢືນຢັນລະຫັດຜ່ານຂອງທ່ານ",
-    "Confirm your password" : "ຢືນຢັນລະຫັດຜ່ານຂອງທ່ານ",
-    "Confirm" : "ຢືນຢັນ",
-    "App token" : "ແອັບ token",
-    "Alternative log in using app token" : "log ທາງເລືອກໃນການນໍາໃຊ້ token app",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "ກະລຸນາໃຊ້  ອັບເດດແຖວຄໍາສັ່ງ ເພາະວ່າທ່ານມີຕົວຢ່າງໃຫຍ່ທີ່ມີຜູ້ໃຊ້ຫຼາຍກວ່າ 50 ຜຸ້ໃຊ້."
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatting, ການໂທວິດີໂອ, screen sharing, ການປະຊຸມອອນໄລນ໌ ແລະ ການປະຊຸມເວັບໄຊ – ໃນເວັບໄຊຂອງທ່ານ ແລະ apps ມືຖື.",
+    "Error loading message template: {error}" : "ການໂຫຼດຂໍ້ຄວາມຜິດພາດ:  {error}"
 },
 "nplurals=1; plural=0;");
