@@ -178,9 +178,6 @@ OC.L10N.register(
     "Back to login form" : "กลับสู่แบบฟอร์มเข้าสู่ระบบ",
     "Back" : "ย้อนกลับ",
     "Login form is disabled." : "ฟอร์มล็อกอินถูกปิดใช้งาน",
-    "Edit Profile" : "แก้ไขโปรไฟล์",
-    "You have not added any info yet" : "คุณยังไม่ได้เพิ่มข้อมูลใด ๆ",
-    "{user} has not added any info yet" : "{user} ยังไม่ได้เพิ่มข้อมูลใด ๆ",
     "This browser is not supported" : "เบราว์เซอร์นี้ไม่ได้รับการสนับสนุน",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "เบราว์เซอร์ของคุณไม่ได้รับการสนับสนุน กรุณาอัปเกรดเป็นรุ่นที่ใหม่กว่าหรือเบราว์เซอร์ที่สนับสนุน",
     "Continue with this unsupported browser" : "ดำเนินการต่อด้วยเบราว์เซอร์นี้ที่ไม่สนับสนุน",
@@ -241,11 +238,9 @@ OC.L10N.register(
     "Admin" : "ผู้ดูแลระบบ",
     "Help" : "ช่วยเหลือ",
     "Access forbidden" : "ไม่ได้รับอนุญาตให้เข้าถึง",
-    "Profile not found" : "ไม่พบโปรไฟล์",
-    "The profile does not exist." : "โปรไฟล์นี้ไม่มีอยู่",
-    "Back to %s" : "กลับสู่ %s",
     "Page not found" : "ไม่พบหน้า",
     "The page could not be found on the server or you may not be allowed to view it." : "ไม่พบหน้านี้บนเซิร์ฟเวอร์ หรือคุณอาจไม่ได้รับอนุญาตให้ดูหน้านี้",
+    "Back to %s" : "กลับสู่ %s",
     "Too many requests" : "มีคำขอมากเกินไป",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "มีการส่งคำขอจากเครือข่ายของคุณมากเกินไป กรุณาลองอีกครั้งในภายหลัง หรือติดต่อผู้ดูแลระบบหากเป็นข้อผิดพลาด",
     "Error" : "ข้อผิดพลาด",
@@ -265,7 +260,6 @@ OC.L10N.register(
     "Security warning" : "คำเตือนความปลอดภัย",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "ไดเรกทอรี data และไฟล์ของคุณอาจเข้าถึงได้จากอินเทอร์เน็ต เพราะไฟล์ .htaccess ไม่ทำงาน",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "สำหรับวิธีการกำหนดค่าเซิร์ฟเวอร์ของคุณอย่างถูกต้อง โปรดดู<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">เอกสารประกอบ</a>",
-    "Create an <strong>admin account</strong>" : "สร้าง<strong>บัญชีผู้ดูแลระบบ</strong>",
     "Show password" : "แสดงรหัสผ่าน",
     "Toggle password visibility" : "เปิด-ปิด การมองเห็นรหัสผ่าน",
     "Storage & database" : "พื้นที่จัดเก็บข้อมูลและฐานข้อมูล",
@@ -345,24 +339,12 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "เซิร์ฟเวอร์ %s นี้อยู่ในโหมดการบำรุงรักษา ซึ่งอาจใช้เวลาสักครู่",
     "This page will refresh itself when the instance is available again." : "หน้านี้จะรีเฟรชตัวเองเมื่อเซิร์ฟเวอร์สามารถใช้ได้อีกครั้ง",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "ติดต่อผู้ดูแลระบบของคุณหากข้อความนี้ยังคงอยู่หรือปรากฏโดยไม่คาดคิด",
-    "The user limit of this instance is reached." : "ถึงขีดจำกัดจำนวนผู้ใช้ของเซิร์ฟเวอร์นี้แล้ว",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "เว็บเซิร์ฟเวอร์ของคุณยังไม่ถูกตั้งค่าอย่างถูกต้องเพื่ออนุญาตการซิงโครไนซ์ไฟล์ เนื่องจากส่วนติดต่อ WebDAV อาจมีปัญหา",
-    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "เซิร์ฟเวอร์เว็บของคุณไม่ได้ตั้งค่าอย่างถูกต้องเพื่อส่งไฟล์ .woff2 ซึ่งเป็นปัญหาที่พบบ่อยในการกำหนดค่า Nginx สำหรับ Nextcloud 15 จำเป็นต้องปรับแต่งเพื่อส่งไฟล์ .woff2 ด้วย โปรดเปรียบเทียบการกำหนดค่า Nginx ของคุณกับการกำหนดค่าที่แนะนำใน{linkstart}เอกสารประกอบ ↗{linkend} ของเรา",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "ส่วนหัว HTTP \"{header}\" ไม่ได้กำหนดค่าให้เท่ากับ \"{expected}\" ดังนั้นจึงมีความเสี่ยงด้านความปลอดภัยหรือความเป็นส่วนตัวที่เป็นไปได้ เราแนะนำให้ปรับการตั้งค่านี้",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "ส่วนหัว HTTP \"{header}\" ไม่ได้กำหนดค่าให้เท่ากับ \"{expected}\" คุณสมบัติบางอย่างอาจไม่สามารถทำงานตามปกติ เราแนะนำให้ปรับการตั้งค่านี้",
     "Currently open" : "เปิดอยู่ในขณะนี้",
-    "Wrong username or password." : "ชื่อผู้ใช้หรือรหัสผ่านไม่ถูกต้อง",
-    "User disabled" : "ผู้ใช้ถูกปิดใช้งาน",
-    "Username or email" : "ชื่อผู้ใช้หรืออีเมล",
+    "Edit Profile" : "แก้ไขโปรไฟล์",
+    "You have not added any info yet" : "คุณยังไม่ได้เพิ่มข้อมูลใด ๆ",
+    "{user} has not added any info yet" : "{user} ยังไม่ได้เพิ่มข้อมูลใด ๆ",
     "Error loading message template: {error}" : "เกิดข้อผิดพลาดขณะกำลังโหลดเทมเพลตข้อความ: {error} ",
-    "Users" : "ผู้ใช้",
-    "Username" : "ชื่อผู้ใช้",
-    "Database user" : "ชื่อผู้ใช้ฐานข้อมูล",
-    "This action requires you to confirm your password" : "การกระทำนี้จำเป็นให้คุณยืนยันรหัสผ่าน",
-    "Confirm your password" : "ยืนยันรหัสผ่านของคุณ",
-    "Confirm" : "ยืนยัน",
-    "App token" : "โทเค็นแอป",
-    "Alternative log in using app token" : "ทางเลือกเข้าสู่ระบบด้วยโทเค็นแอป",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "กรุณาใช้ตัวอัปเดตผ่านบรรทัดคำสั่ง เนื่องจากคุณมีเซิร์ฟเวอร์ขนาดใหญ่ที่มีจำนวนผู้ใช้มากกว่า 50 ผู้ใช้"
+    "Profile not found" : "ไม่พบโปรไฟล์",
+    "The profile does not exist." : "โปรไฟล์นี้ไม่มีอยู่"
 },
 "nplurals=1; plural=0;");
